@@ -18,10 +18,9 @@
 
 #pragma once
 
-#include "system.hpp"
-
 #include "NonCopyable.hpp"
 
+#include <cstdio>
 #include <string>
 
 class File : public NonCopyable
