@@ -20,10 +20,10 @@
 
 class NonCopyable
 {
-protected:
-  NonCopyable() = default;
-
-private:
+public:
   NonCopyable(const NonCopyable&) = delete;
   NonCopyable& operator=(const NonCopyable&) = delete;
+
+protected:
+  NonCopyable() = default;
 };
