@@ -1,4 +1,4 @@
-// Copyright (C) 2019-2020 Joel Rosdahl and other contributors
+// Copyright (C) 2019-2021 Joel Rosdahl and other contributors
 //
 // See doc/AUTHORS.adoc for a complete list of contributors.
 //
@@ -18,14 +18,16 @@
 
 #include "Stat.hpp"
 
-#ifdef _WIN32
-#  include "Win32Util.hpp"
-
-#  include "third_party/win32/winerror_to_errno.h"
-#endif
-
 #include "Finalizer.hpp"
 #include "Logging.hpp"
+#include "Win32Util.hpp"
+
+#include <core/exceptions.hpp>
+#include <core/wincompat.hpp>
+
+#ifdef _WIN32
+#  include <third_party/win32/winerror_to_errno.h>
+#endif
 
 namespace {
 
@@ -210,7 +212,7 @@ Stat::Stat(StatFunction stat_function,
   } else {
     m_errno = errno;
     if (on_error == OnError::throw_error) {
-      throw Error("failed to stat {}: {}", path, strerror(errno));
+      throw core::Error("failed to stat {}: {}", path, strerror(errno));
     }
     if (on_error == OnError::log) {
       LOG("Failed to stat {}: {}", path, strerror(errno));
