@@ -1,4 +1,4 @@
-// Copyright (C) 2019-2020 Joel Rosdahl and other contributors
+// Copyright (C) 2019-2021 Joel Rosdahl and other contributors
 //
 // See doc/AUTHORS.adoc for a complete list of contributors.
 //
@@ -18,12 +18,44 @@
 
 #pragma once
 
-#include "system.hpp"
+#include <core/wincompat.hpp>
 
-#include "exceptions.hpp"
+#include <sys/stat.h>
+#include <sys/types.h>
 
+#include <ctime>
 #include <string>
 
+#ifdef _WIN32
+#  ifndef S_IFIFO
+#    define S_IFIFO 0x1000
+#  endif
+#  ifndef S_IFBLK
+#    define S_IFBLK 0x6000
+#  endif
+#  ifndef S_IFLNK
+#    define S_IFLNK 0xA000
+#  endif
+#  ifndef S_ISREG
+#    define S_ISREG(m) (((m)&S_IFMT) == S_IFREG)
+#  endif
+#  ifndef S_ISDIR
+#    define S_ISDIR(m) (((m)&S_IFMT) == S_IFDIR)
+#  endif
+#  ifndef S_ISFIFO
+#    define S_ISFIFO(m) (((m)&S_IFMT) == S_IFIFO)
+#  endif
+#  ifndef S_ISCHR
+#    define S_ISCHR(m) (((m)&S_IFMT) == S_IFCHR)
+#  endif
+#  ifndef S_ISLNK
+#    define S_ISLNK(m) (((m)&S_IFMT) == S_IFLNK)
+#  endif
+#  ifndef S_ISBLK
+#    define S_ISBLK(m) (((m)&S_IFMT) == S_IFBLK)
+#  endif
+#endif
+
 class Stat
 {
 public:
@@ -94,6 +126,7 @@ public:
   dev_t device() const;
   ino_t inode() const;
   mode_t mode() const;
+  time_t atime() const;
   time_t ctime() const;
   time_t mtime() const;
   uint64_t size() const;
@@ -109,6 +142,7 @@ public:
   uint32_t reparse_tag() const;
 #endif
 
+  timespec atim() const;
   timespec ctim() const;
   timespec mtim() const;
 
@@ -164,6 +198,12 @@ Stat::mode() const
   return m_stat.st_mode;
 }
 
+inline time_t
+Stat::atime() const
+{
+  return atim().tv_sec;
+}
+
 inline time_t
 Stat::ctime() const
 {
@@ -224,6 +264,16 @@ Stat::reparse_tag() const
 }
 #endif
 
+inline timespec
+Stat::atim() const
+{
+#if defined(_WIN32) || defined(HAVE_STRUCT_STAT_ST_ATIM)
+  return m_stat.st_atim;
+#else
+  return {m_stat.st_atime, 0};
+#endif
+}
+
 inline timespec
 Stat::ctim() const
 {
