@@ -21,16 +21,32 @@
 #include "Config.hpp"
 #include "Context.hpp"
 #include "Fd.hpp"
-#include "FormatNonstdStringView.hpp"
 #include "Logging.hpp"
 #include "TemporaryFile.hpp"
+#include "Win32Util.hpp"
 #include "fmtmacros.hpp"
 
+#include <core/exceptions.hpp>
+#include <core/wincompat.hpp>
+#include <util/path.hpp>
+#include <util/string.hpp>
+
 extern "C" {
 #include "third_party/base32hex.h"
 }
 
+#ifdef HAVE_DIRENT_H
+#  include <dirent.h>
+#endif
+
+#ifdef HAVE_UNISTD_H
+#  include <unistd.h>
+#endif
+
+#include <fcntl.h>
+
 #include <algorithm>
+#include <climits>
 #include <fstream>
 
 #ifndef HAVE_DIRENT_H
@@ -45,6 +61,12 @@ extern "C" {
 #  include <sys/time.h>
 #endif
 
+#ifdef HAVE_UTIME_H
+#  include <utime.h>
+#elif defined(HAVE_SYS_UTIME_H)
+#  include <sys/utime.h>
+#endif
+
 #ifdef HAVE_LINUX_FS_H
 #  include <linux/magic.h>
 #  include <sys/statfs.h>
@@ -53,10 +75,6 @@ extern "C" {
 #  include <sys/param.h>
 #endif
 
-#ifdef _WIN32
-#  include "Win32Util.hpp"
-#endif
-
 #ifdef __linux__
 #  ifdef HAVE_SYS_IOCTL_H
 #    include <sys/ioctl.h>
@@ -136,26 +154,14 @@ path_max(const std::string& path)
 
 template<typename T>
 std::vector<T>
-split_at(string_view input, const char* separators)
+split_into(string_view string,
+           const char* separators,
+           util::Tokenizer::Mode mode)
 {
-  ASSERT(separators != nullptr && separators[0] != '\0');
-
   std::vector<T> result;
-
-  size_t start = 0;
-  while (start < input.size()) {
-    size_t end = input.find_first_of(separators, start);
-
-    if (end == string_view::npos) {
-      result.emplace_back(input.data() + start, input.size() - start);
-      break;
-    } else if (start != end) {
-      result.emplace_back(input.data() + start, end - start);
-    }
-
-    start = end + 1;
+  for (const auto token : util::Tokenizer(string, separators, mode)) {
+    result.emplace_back(token);
   }
-
   return result;
 }
 
@@ -165,14 +171,15 @@ rewrite_stderr_to_absolute_paths(string_view text)
   static const std::string in_file_included_from = "In file included from ";
 
   std::string result;
-  for (auto line : Util::split_into_views(text, "\n")) {
+  for (auto line :
+       util::Tokenizer(text, "\n", util::Tokenizer::Mode::skip_last_empty)) {
     // Rewrite <path> to <absolute path> in the following two cases, where X may
     // be optional ANSI CSI sequences:
     //
     // In file included from X<path>X:1:
     // X<path>X:1:2: ...
 
-    if (Util::starts_with(line, in_file_included_from)) {
+    if (util::starts_with(line, in_file_included_from)) {
       result += in_file_included_from;
       line = line.substr(in_file_included_from.length());
     }
@@ -229,7 +236,7 @@ clone_file(const std::string& src, const std::string& dest, bool via_tmp_file)
 #  if defined(__linux__)
   Fd src_fd(open(src.c_str(), O_RDONLY));
   if (!src_fd) {
-    throw Error("{}: {}", src, strerror(errno));
+    throw core::Error("{}: {}", src, strerror(errno));
   }
 
   Fd dest_fd;
@@ -242,12 +249,12 @@ clone_file(const std::string& src, const std::string& dest, bool via_tmp_file)
     dest_fd =
       Fd(open(dest.c_str(), O_WRONLY | O_CREAT | O_TRUNC | O_BINARY, 0666));
     if (!dest_fd) {
-      throw Error("{}: {}", src, strerror(errno));
+      throw core::Error("{}: {}", src, strerror(errno));
     }
   }
 
   if (ioctl(*dest_fd, FICLONE, *src_fd) != 0) {
-    throw Error(strerror(errno));
+    throw core::Error(strerror(errno));
   }
 
   dest_fd.close();
@@ -259,13 +266,13 @@ clone_file(const std::string& src, const std::string& dest, bool via_tmp_file)
 #  elif defined(__APPLE__)
   (void)via_tmp_file;
   if (clonefile(src.c_str(), dest.c_str(), CLONE_NOOWNERCOPY) != 0) {
-    throw Error(strerror(errno));
+    throw core::Error(strerror(errno));
   }
 #  else
   (void)src;
   (void)dest;
   (void)via_tmp_file;
-  throw Error(strerror(EOPNOTSUPP));
+  throw core::Error(strerror(EOPNOTSUPP));
 #  endif
 }
 #endif // FILE_CLONING_SUPPORTED
@@ -282,7 +289,7 @@ clone_hard_link_or_copy_file(const Context& ctx,
     try {
       clone_file(source, dest, via_tmp_file);
       return;
-    } catch (Error& e) {
+    } catch (core::Error& e) {
       LOG("Failed to clone: {}", e.what());
     }
 #else
@@ -297,7 +304,7 @@ clone_hard_link_or_copy_file(const Context& ctx,
         LOG("Failed to chmod: {}", strerror(errno));
       }
       return;
-    } catch (const Error& e) {
+    } catch (const core::Error& e) {
       LOG_RAW(e.what());
       // Fall back to copying.
     }
@@ -349,7 +356,7 @@ copy_file(const std::string& src, const std::string& dest, bool via_tmp_file)
 {
   Fd src_fd(open(src.c_str(), O_RDONLY));
   if (!src_fd) {
-    throw Error("{}: {}", src, strerror(errno));
+    throw core::Error("{}: {}", src, strerror(errno));
   }
 
   Fd dest_fd;
@@ -362,7 +369,7 @@ copy_file(const std::string& src, const std::string& dest, bool via_tmp_file)
     dest_fd =
       Fd(open(dest.c_str(), O_WRONLY | O_CREAT | O_TRUNC | O_BINARY, 0666));
     if (!dest_fd) {
-      throw Error("{}: {}", dest, strerror(errno));
+      throw core::Error("{}: {}", dest, strerror(errno));
     }
   }
 
@@ -448,7 +455,7 @@ expand_environment_variables(const std::string& str)
         ++right;
       }
       if (curly && *right != '}') {
-        throw Error("syntax error: missing '}}' after \"{}\"", left);
+        throw core::Error("syntax error: missing '}}' after \"{}\"", left);
       }
       if (right == left) {
         // Special case: don't consider a single $ the left of a variable.
@@ -458,7 +465,7 @@ expand_environment_variables(const std::string& str)
         std::string name(left, right - left);
         const char* value = getenv(name.c_str());
         if (!value) {
-          throw Error("environment variable \"{}\" not set", name);
+          throw core::Error("environment variable \"{}\" not set", name);
         }
         result += value;
         if (!curly) {
@@ -498,7 +505,7 @@ fallocate(int fd, long new_size)
   int err = 0;
   try {
     write_fd(fd, buf, bytes_to_write);
-  } catch (Error&) {
+  } catch (core::Error&) {
     err = errno;
   }
   lseek(fd, saved_pos, SEEK_SET);
@@ -507,22 +514,6 @@ fallocate(int fd, long new_size)
 #endif
 }
 
-void
-for_each_level_1_subdir(const std::string& cache_dir,
-                        const SubdirVisitor& visitor,
-                        const ProgressReceiver& progress_receiver)
-{
-  for (int i = 0; i <= 0xF; i++) {
-    double progress = 1.0 * i / 16;
-    progress_receiver(progress);
-    std::string subdir_path = FMT("{}/{:x}", cache_dir, i);
-    visitor(subdir_path, [&](double inner_progress) {
-      progress_receiver(progress + inner_progress / 16);
-    });
-  }
-  progress_receiver(1.0);
-}
-
 std::string
 format_argv_for_logging(const char* const* argv)
 {
@@ -589,7 +580,8 @@ void
 ensure_dir_exists(nonstd::string_view dir)
 {
   if (!create_dir(dir)) {
-    throw Fatal("Failed to create directory {}: {}", dir, strerror(errno));
+    throw core::Fatal(
+      "Failed to create directory {}: {}", dir, strerror(errno));
   }
 }
 
@@ -617,7 +609,7 @@ get_apparent_cwd(const std::string& actual_cwd)
   return actual_cwd;
 #else
   auto pwd = getenv("PWD");
-  if (!pwd) {
+  if (!pwd || !util::is_absolute_path(pwd)) {
     return actual_cwd;
   }
 
@@ -654,37 +646,6 @@ get_extension(string_view path)
   }
 }
 
-std::vector<CacheFile>
-get_level_1_files(const std::string& dir,
-                  const ProgressReceiver& progress_receiver)
-{
-  std::vector<CacheFile> files;
-
-  if (!Stat::stat(dir)) {
-    return files;
-  }
-
-  size_t level_2_directories = 0;
-
-  Util::traverse(dir, [&](const std::string& path, bool is_dir) {
-    auto name = Util::base_name(path);
-    if (name == "CACHEDIR.TAG" || name == "stats" || name.starts_with(".nfs")) {
-      return;
-    }
-
-    if (!is_dir) {
-      files.emplace_back(path);
-    } else if (path != dir
-               && path.find('/', dir.size() + 1) == std::string::npos) {
-      ++level_2_directories;
-      progress_receiver(level_2_directories / 16.0);
-    }
-  });
-
-  progress_receiver(1.0);
-  return files;
-}
-
 std::string
 get_home_directory()
 {
@@ -706,7 +667,8 @@ get_home_directory()
     }
   }
 #endif
-  throw Fatal("Could not determine home directory from $HOME or getpwuid(3)");
+  throw core::Fatal(
+    "Could not determine home directory from $HOME or getpwuid(3)");
 }
 
 const char*
@@ -728,8 +690,8 @@ get_hostname()
 std::string
 get_relative_path(string_view dir, string_view path)
 {
-  ASSERT(Util::is_absolute_path(dir));
-  ASSERT(Util::is_absolute_path(path));
+  ASSERT(util::is_absolute_path(dir));
+  ASSERT(util::is_absolute_path(path));
 
 #ifdef _WIN32
   // Paths can be escaped by a slash for use with e.g. -isystem.
@@ -769,27 +731,6 @@ get_relative_path(string_view dir, string_view path)
   return result.empty() ? "." : result;
 }
 
-std::string
-get_path_in_cache(string_view cache_dir, uint8_t level, string_view name)
-{
-  ASSERT(level >= 1 && level <= 8);
-  ASSERT(name.length() >= level);
-
-  std::string path(cache_dir);
-  path.reserve(path.size() + level * 2 + 1 + name.length() - level);
-
-  for (uint8_t i = 0; i < level; ++i) {
-    path.push_back('/');
-    path.push_back(name.at(i));
-  }
-
-  path.push_back('/');
-  string_view name_remaining = name.substr(level);
-  path.append(name_remaining.data(), name_remaining.length());
-
-  return path;
-}
-
 void
 hard_link(const std::string& oldpath, const std::string& newpath)
 {
@@ -800,32 +741,20 @@ hard_link(const std::string& oldpath, const std::string& newpath)
 
 #ifndef _WIN32
   if (link(oldpath.c_str(), newpath.c_str()) != 0) {
-    throw Error(
+    throw core::Error(
       "failed to link {} to {}: {}", oldpath, newpath, strerror(errno));
   }
 #else
   if (!CreateHardLink(newpath.c_str(), oldpath.c_str(), nullptr)) {
     DWORD error = GetLastError();
-    throw Error("failed to link {} to {}: {}",
-                oldpath,
-                newpath,
-                Win32Util::error_message(error));
+    throw core::Error("failed to link {} to {}: {}",
+                      oldpath,
+                      newpath,
+                      Win32Util::error_message(error));
   }
 #endif
 }
 
-bool
-is_absolute_path(string_view path)
-{
-#ifdef _WIN32
-  if (path.length() >= 2 && path[1] == ':'
-      && (path[2] == '/' || path[2] == '\\')) {
-    return true;
-  }
-#endif
-  return !path.empty() && path[0] == '/';
-}
-
 #if defined(HAVE_LINUX_FS_H) || defined(HAVE_STRUCT_STATFS_F_FSTYPENAME)
 int
 is_nfs_fd(int fd, bool* is_nfs)
@@ -875,7 +804,7 @@ make_relative_path(const std::string& base_dir,
                    const std::string& apparent_cwd,
                    nonstd::string_view path)
 {
-  if (base_dir.empty() || !Util::starts_with(path, base_dir)) {
+  if (base_dir.empty() || !util::starts_with(path, base_dir)) {
     return std::string(path);
   }
 
@@ -907,7 +836,7 @@ make_relative_path(const std::string& base_dir,
   const auto path_suffix = std::string(original_path.substr(path.length()));
   const auto real_path = Util::real_path(std::string(path));
 
-  const auto add_relpath_candidates = [&](nonstd::string_view path) {
+  const auto add_relpath_candidates = [&](auto path) {
     const std::string normalized_path = Util::normalize_absolute_path(path);
     relpath_candidates.push_back(
       Util::get_relative_path(actual_cwd, normalized_path));
@@ -924,7 +853,7 @@ make_relative_path(const std::string& base_dir,
   // Find best (i.e. shortest existing) match:
   std::sort(relpath_candidates.begin(),
             relpath_candidates.end(),
-            [](const std::string& path1, const std::string& path2) {
+            [](const auto& path1, const auto& path2) {
               return path1.length() < path2.length();
             });
   for (const auto& relpath : relpath_candidates) {
@@ -958,7 +887,7 @@ matches_dir_prefix_or_file(string_view dir_prefix_or_file, string_view path)
 std::string
 normalize_absolute_path(string_view path)
 {
-  if (!is_absolute_path(path)) {
+  if (!util::is_absolute_path(path)) {
     return std::string(path);
   }
 
@@ -1028,40 +957,17 @@ parse_duration(const std::string& duration)
     factor = 1;
     break;
   default:
-    throw Error("invalid suffix (supported: d (day) and s (second)): \"{}\"",
-                duration);
+    throw core::Error(
+      "invalid suffix (supported: d (day) and s (second)): \"{}\"", duration);
   }
 
-  return factor * parse_unsigned(duration.substr(0, duration.length() - 1));
-}
-
-int64_t
-parse_signed(const std::string& value,
-             optional<int64_t> min_value,
-             optional<int64_t> max_value,
-             string_view description)
-{
-  std::string stripped_value = strip_whitespace(value);
-
-  size_t end = 0;
-  long long result = 0;
-  bool failed = false;
-  try {
-    // Note: sizeof(long long) is guaranteed to be >= sizeof(int64_t)
-    result = std::stoll(stripped_value, &end, 10);
-  } catch (std::exception&) {
-    failed = true;
+  const auto value =
+    util::parse_unsigned(duration.substr(0, duration.length() - 1));
+  if (value) {
+    return factor * *value;
+  } else {
+    throw core::Error(value.error());
   }
-  if (failed || end != stripped_value.size()) {
-    throw Error("invalid integer: \"{}\"", stripped_value);
-  }
-
-  int64_t min = min_value ? *min_value : INT64_MIN;
-  int64_t max = max_value ? *max_value : INT64_MAX;
-  if (result < min || result > max) {
-    throw Error("{} must be between {} and {}", description, min, max);
-  }
-  return result;
 }
 
 uint64_t
@@ -1072,7 +978,7 @@ parse_size(const std::string& value)
   char* p;
   double result = strtod(value.c_str(), &p);
   if (errno != 0 || result < 0 || p == value.c_str() || value.empty()) {
-    throw Error("invalid size: \"{}\"", value);
+    throw core::Error("invalid size: \"{}\"", value);
   }
 
   while (isspace(*p)) {
@@ -1096,7 +1002,7 @@ parse_size(const std::string& value)
       result *= multiplier;
       break;
     default:
-      throw Error("invalid size: \"{}\"", value);
+      throw core::Error("invalid size: \"{}\"", value);
     }
   } else {
     // Default suffix: G.
@@ -1105,45 +1011,11 @@ parse_size(const std::string& value)
   return static_cast<uint64_t>(result);
 }
 
-uint64_t
-parse_unsigned(const std::string& value,
-               optional<uint64_t> min_value,
-               optional<uint64_t> max_value,
-               string_view description)
-{
-  std::string stripped_value = strip_whitespace(value);
-
-  size_t end = 0;
-  unsigned long long result = 0;
-  bool failed = false;
-  if (Util::starts_with(stripped_value, "-")) {
-    failed = true;
-  } else {
-    try {
-      // Note: sizeof(unsigned long long) is guaranteed to be >=
-      // sizeof(uint64_t)
-      result = std::stoull(stripped_value, &end, 10);
-    } catch (std::exception&) {
-      failed = true;
-    }
-  }
-  if (failed || end != stripped_value.size()) {
-    throw Error("invalid unsigned integer: \"{}\"", stripped_value);
-  }
-
-  uint64_t min = min_value ? *min_value : 0;
-  uint64_t max = max_value ? *max_value : UINT64_MAX;
-  if (result < min || result > max) {
-    throw Error("{} must be between {} and {}", description, min, max);
-  }
-  return result;
-}
-
 bool
 read_fd(int fd, DataReceiver data_receiver)
 {
-  ssize_t n;
-  char buffer[READ_BUFFER_SIZE];
+  int64_t n;
+  char buffer[CCACHE_READ_BUFFER_SIZE];
   while ((n = read(fd, buffer, sizeof(buffer))) != 0) {
     if (n == -1 && errno != EINTR) {
       break;
@@ -1161,7 +1033,7 @@ read_file(const std::string& path, size_t size_hint)
   if (size_hint == 0) {
     auto stat = Stat::stat(path);
     if (!stat) {
-      throw Error(strerror(errno));
+      throw core::Error(strerror(errno));
     }
     size_hint = stat.size();
   }
@@ -1171,10 +1043,10 @@ read_file(const std::string& path, size_t size_hint)
 
   Fd fd(open(path.c_str(), O_RDONLY | O_BINARY));
   if (!fd) {
-    throw Error(strerror(errno));
+    throw core::Error(strerror(errno));
   }
 
-  ssize_t ret = 0;
+  int64_t ret = 0;
   size_t pos = 0;
   std::string result;
   result.resize(size_hint);
@@ -1198,7 +1070,7 @@ read_file(const std::string& path, size_t size_hint)
 
   if (ret == -1) {
     LOG("Failed reading {}", path);
-    throw Error(strerror(errno));
+    throw core::Error(strerror(errno));
   }
 
   result.resize(pos);
@@ -1211,7 +1083,7 @@ read_link(const std::string& path)
 {
   size_t buffer_size = path_max(path);
   std::unique_ptr<char[]> buffer(new char[buffer_size]);
-  ssize_t len = readlink(path.c_str(), buffer.get(), buffer_size - 1);
+  const auto len = readlink(path.c_str(), buffer.get(), buffer_size - 1);
   if (len == -1) {
     return "";
   }
@@ -1272,7 +1144,7 @@ rename(const std::string& oldpath, const std::string& newpath)
 {
 #ifndef _WIN32
   if (::rename(oldpath.c_str(), newpath.c_str()) != 0) {
-    throw Error(
+    throw core::Error(
       "failed to rename {} to {}: {}", oldpath, newpath, strerror(errno));
   }
 #else
@@ -1281,10 +1153,10 @@ rename(const std::string& oldpath, const std::string& newpath)
   if (!MoveFileExA(
         oldpath.c_str(), newpath.c_str(), MOVEFILE_REPLACE_EXISTING)) {
     DWORD error = GetLastError();
-    throw Error("failed to rename {} to {}: {}",
-                oldpath,
-                newpath,
-                Win32Util::error_message(error));
+    throw core::Error("failed to rename {} to {}: {}",
+                      oldpath,
+                      newpath,
+                      Win32Util::error_message(error));
   }
 #endif
 }
@@ -1312,7 +1184,7 @@ send_to_stderr(const Context& ctx, const std::string& text)
     try {
       modified_text = strip_ansi_csi_seqs(text);
       text_to_send = &modified_text;
-    } catch (const Error&) {
+    } catch (const core::Error&) {
       // Fall through
     }
   }
@@ -1324,8 +1196,8 @@ send_to_stderr(const Context& ctx, const std::string& text)
 
   try {
     write_fd(STDERR_FILENO, text_to_send->data(), text_to_send->length());
-  } catch (Error& e) {
-    throw Error("Failed to write to stderr: {}", e.what());
+  } catch (core::Error& e) {
+    throw core::Error("Failed to write to stderr: {}", e.what());
   }
 }
 
@@ -1355,15 +1227,19 @@ setenv(const std::string& name, const std::string& value)
 }
 
 std::vector<string_view>
-split_into_views(string_view input, const char* separators)
+split_into_views(string_view string,
+                 const char* separators,
+                 util::Tokenizer::Mode mode)
 {
-  return split_at<string_view>(input, separators);
+  return split_into<string_view>(string, separators, mode);
 }
 
 std::vector<std::string>
-split_into_strings(string_view input, const char* separators)
+split_into_strings(string_view string,
+                   const char* separators,
+                   util::Tokenizer::Mode mode)
 {
-  return split_at<std::string>(input, separators);
+  return split_into<std::string>(string, separators, mode);
 }
 
 std::string
@@ -1388,15 +1264,6 @@ strip_ansi_csi_seqs(string_view string)
   return result;
 }
 
-std::string
-strip_whitespace(string_view string)
-{
-  auto is_space = [](int ch) { return std::isspace(ch); };
-  auto start = std::find_if_not(string.begin(), string.end(), is_space);
-  auto end = std::find_if_not(string.rbegin(), string.rend(), is_space).base();
-  return start < end ? std::string(start, end) : std::string();
-}
-
 std::string
 to_lowercase(string_view string)
 {
@@ -1433,9 +1300,9 @@ traverse(const std::string& path, const TraverseVisitor& visitor)
           if (stat.error_number() == ENOENT || stat.error_number() == ESTALE) {
             continue;
           }
-          throw Error("failed to lstat {}: {}",
-                      entry_path,
-                      strerror(stat.error_number()));
+          throw core::Error("failed to lstat {}: {}",
+                            entry_path,
+                            strerror(stat.error_number()));
         }
         is_dir = stat.is_directory();
       }
@@ -1450,7 +1317,7 @@ traverse(const std::string& path, const TraverseVisitor& visitor)
   } else if (errno == ENOTDIR) {
     visitor(path, false);
   } else {
-    throw Error("failed to open directory {}: {}", path, strerror(errno));
+    throw core::Error("failed to open directory {}: {}", path, strerror(errno));
   }
 }
 
@@ -1473,7 +1340,7 @@ traverse(const std::string& path, const TraverseVisitor& visitor)
   } else if (std::filesystem::exists(path)) {
     visitor(path, false);
   } else {
-    throw Error("failed to open directory {}: {}", path, strerror(errno));
+    throw core::Error("failed to open directory {}: {}", path, strerror(errno));
   }
 }
 
@@ -1492,7 +1359,7 @@ unlink_safe(const std::string& path, UnlinkLog unlink_log)
   bool success = true;
   try {
     Util::rename(path, tmp_name);
-  } catch (Error&) {
+  } catch (core::Error&) {
     success = false;
     saved_errno = errno;
   }
@@ -1562,10 +1429,10 @@ wipe_path(const std::string& path)
   traverse(path, [](const std::string& p, bool is_dir) {
     if (is_dir) {
       if (rmdir(p.c_str()) != 0 && errno != ENOENT && errno != ESTALE) {
-        throw Error("failed to rmdir {}: {}", p, strerror(errno));
+        throw core::Error("failed to rmdir {}: {}", p, strerror(errno));
       }
     } else if (unlink(p.c_str()) != 0 && errno != ENOENT && errno != ESTALE) {
-      throw Error("failed to unlink {}: {}", p, strerror(errno));
+      throw core::Error("failed to unlink {}: {}", p, strerror(errno));
     }
   });
 }
@@ -1573,13 +1440,13 @@ wipe_path(const std::string& path)
 void
 write_fd(int fd, const void* data, size_t size)
 {
-  ssize_t written = 0;
+  int64_t written = 0;
   do {
-    ssize_t count =
+    const auto count =
       write(fd, static_cast<const uint8_t*>(data) + written, size - written);
     if (count == -1) {
       if (errno != EAGAIN && errno != EINTR) {
-        throw Error(strerror(errno));
+        throw core::Error(strerror(errno));
       }
     } else {
       written += count;
@@ -1593,13 +1460,13 @@ write_file(const std::string& path,
            std::ios_base::openmode open_mode)
 {
   if (path.empty()) {
-    throw Error("No such file or directory");
+    throw core::Error("No such file or directory");
   }
 
   open_mode |= std::ios::out;
   std::ofstream file(path, open_mode);
   if (!file) {
-    throw Error(strerror(errno));
+    throw core::Error(strerror(errno));
   }
   file << data;
 }
