@@ -19,6 +19,7 @@
 #include "assertions.hpp"
 
 #include "Util.hpp"
+#include "fmtmacros.hpp"
 
 #include "third_party/fmt/core.h"
 
@@ -28,11 +29,11 @@ handle_failed_assertion(const char* file,
                         const char* function,
                         const char* condition)
 {
-  fmt::print(stderr,
-             "ccache: {}:{}: {}: failed assertion: {}\n",
-             Util::base_name(file),
-             line,
-             function,
-             condition);
+  PRINT(stderr,
+        "ccache: {}:{}: {}: failed assertion: {}\n",
+        Util::base_name(file),
+        line,
+        function,
+        condition);
   abort();
 }
