@@ -25,14 +25,14 @@
 namespace compression {
 
 std::unique_ptr<Decompressor>
-Decompressor::create_from_type(Type type, FILE* stream)
+Decompressor::create_from_type(Type type, core::Reader& reader)
 {
   switch (type) {
   case compression::Type::none:
-    return std::make_unique<NullDecompressor>(stream);
+    return std::make_unique<NullDecompressor>(reader);
 
   case compression::Type::zstd:
-    return std::make_unique<ZstdDecompressor>(stream);
+    return std::make_unique<ZstdDecompressor>(reader);
   }
 
   ASSERT(false);
