@@ -1,4 +1,4 @@
-// Copyright (C) 2020 Joel Rosdahl and other contributors
+// Copyright (C) 2020-2021 Joel Rosdahl and other contributors
 //
 // See doc/AUTHORS.adoc for a complete list of contributors.
 //
@@ -18,8 +18,7 @@
 
 #pragma once
 
-#include "system.hpp"
-
+#include <cstddef>
 #include <string>
 
 #ifdef _MSC_VER
