@@ -1,4 +1,4 @@
-// Copyright (C) 2019-2020 Joel Rosdahl and other contributors
+// Copyright (C) 2019-2021 Joel Rosdahl and other contributors
 //
 // See doc/AUTHORS.adoc for a complete list of contributors.
 //
@@ -21,6 +21,9 @@
 #include "../src/Util.hpp"
 #include "TestUtil.hpp"
 
+#include <core/exceptions.hpp>
+#include <core/wincompat.hpp>
+
 #include "third_party/doctest.h"
 
 #ifdef HAVE_UNISTD_H
@@ -618,7 +621,7 @@ TEST_CASE("Win32 No Sharing")
   Finalizer cleanup([&] { CloseHandle(handle); });
 
   // Sanity check we can't open the file for read/write access.
-  REQUIRE_THROWS_AS(Util::read_file("file"), const Error&);
+  REQUIRE_THROWS_AS(Util::read_file("file"), const core::Error&);
 
   SUBCASE("stat file no sharing")
   {
